@@ -9,6 +9,7 @@ import logging
 import os
 import rdkit.Chem.AllChem as rdkit
 from functools import partial
+import warnings
 
 from ..functional_groups import FunctionalGroup
 from ..atoms import Atom
@@ -60,7 +61,8 @@ class BuildingBlock(Molecule):
         smiles,
         functional_groups=(),
         placer_ids=None,
-        random_seed=4,
+        random_seed=None,
+        position_matrix=None,
     ):
         """
         Initialize a :class:`.BuildingBlock`.
@@ -68,7 +70,7 @@ class BuildingBlock(Molecule):
         Notes
         -----
         The molecule is given 3D coordinates with
-        :func:`rdkit.ETKDGv2()`.
+        :func:`rdkit.ETKDGv2`.
 
         Parameters
         ----------
@@ -106,7 +108,17 @@ class BuildingBlock(Molecule):
                *placer* ids.
 
         random_seed : :class:`int`, optional
-            Random seed passed to :func:`rdkit.ETKDGv2`
+            Random seed passed to :func:`rdkit.ETKDGv2`. This
+            argument is deprecated and will be removed in any
+            version of :mod:`stk` released on, or after, 01/08/20.
+            If you want to change the position matrix of the
+            initialized building block, please use
+            `position_matrix`.
+
+        position_matrix : :class:`numpy.ndarray`, optional
+            The position matrix the building block should use. If
+            ``None``, :func:`rdkit.ETKDGv2` will be used to calculate
+            it.
 
         Raises
         ------
@@ -115,14 +127,35 @@ class BuildingBlock(Molecule):
 
         """
 
-        molecule = rdkit.AddHs(rdkit.MolFromSmiles(smiles))
-        params = rdkit.ETKDGv2()
-        params.randomSeed = random_seed
-        if rdkit.EmbedMolecule(molecule, params) == -1:
-            raise RuntimeError(
-                f'Embedding with seed value of {random_seed} failed.'
+        if random_seed is not None:
+            warnings.warn(
+                'The BuildingBlock random seed parameter will be '
+                'removed in any '
+                'version of stk released on, or after, 01/08/20. '
+                'If you want to change the position matrix of the '
+                'initialized building block, please use the '
+                'position_matrix parameter.',
+                FutureWarning,
             )
-        rdkit.Kekulize(molecule)
+        else:
+            random_seed = 4
+
+        molecule = rdkit.AddHs(rdkit.MolFromSmiles(smiles))
+        if position_matrix is None:
+            params = rdkit.ETKDGv2()
+            params.randomSeed = random_seed
+            if rdkit.EmbedMolecule(molecule, params) == -1:
+                raise RuntimeError(
+                    f'Embedding with seed value of {random_seed} '
+                    'failed.'
+                )
+            rdkit.Kekulize(molecule)
+        else:
+            conformer = rdkit.Conformer(molecule.GetNumAtoms())
+            for atom_id, position in enumerate(position_matrix):
+                conformer.SetAtomPosition(atom_id, position)
+            molecule.AddConformer(conformer)
+
         self._init_from_rdkit_mol(
             molecule=molecule,
             functional_groups=functional_groups,
@@ -196,7 +229,8 @@ class BuildingBlock(Molecule):
         molecule,
         functional_groups=(),
         placer_ids=None,
-        random_seed=4,
+        random_seed=None,
+        position_matrix=None,
     ):
         """
         Initialize from a :mod:`vabene.Molecule`.
@@ -242,7 +276,17 @@ class BuildingBlock(Molecule):
                *placer* ids.
 
         random_seed : :class:`int`, optional
-            Random seed passed to :func:`rdkit.ETKDGv2`
+            Random seed passed to :func:`rdkit.ETKDGv2`. This
+            argument is deprecated and will be removed in any
+            version of :mod:`stk` released on, or after, 01/08/20.
+            If you want to change the position matrix of the
+            initialized building block, please use
+            `position_matrix`.
+
+        position_matrix : :class:`numpy.ndarray`, optional
+            The position matrix the building block should use. If
+            ``None``, :func:`rdkit.ETKDGv2` will be used to calculate
+            it.
 
         Returns
         -------
@@ -256,6 +300,19 @@ class BuildingBlock(Molecule):
 
         """
 
+        if random_seed is not None:
+            warnings.warn(
+                'The init_from_vabene_molecule random seed parameter '
+                'will be removed in any '
+                'version of stk released on, or after, 01/08/20. '
+                'If you want to change the position matrix of the '
+                'initialized building block, please use the '
+                'position_matrix parameter.',
+                FutureWarning,
+            )
+        else:
+            random_seed = 4
+
         editable = rdkit.EditableMol(rdkit.Mol())
         for atom in molecule.get_atoms():
             rdkit_atom = rdkit.Atom(atom.get_atomic_number())
@@ -272,12 +329,21 @@ class BuildingBlock(Molecule):
         rdkit_molecule = editable.GetMol()
         rdkit.SanitizeMol(rdkit_molecule)
         rdkit_molecule = rdkit.AddHs(rdkit_molecule)
-        params = rdkit.ETKDGv2()
-        params.randomSeed = random_seed
-        if rdkit.EmbedMolecule(rdkit_molecule, params) == -1:
-            raise RuntimeError(
-                f'Embedding with seed value of {random_seed} failed.'
-            )
+
+        if position_matrix is None:
+            params = rdkit.ETKDGv2()
+            params.randomSeed = random_seed
+            if rdkit.EmbedMolecule(rdkit_molecule, params) == -1:
+                raise RuntimeError(
+                    f'Embedding with seed value of {random_seed} '
+                    'failed.'
+                )
+        else:
+            conformer = rdkit.Conformer(rdkit_molecule.GetNumAtoms())
+            for atom_id, position in enumerate(position_matrix):
+                conformer.SetAtomPosition(atom_id, position)
+            rdkit_molecule.AddConformer(conformer)
+
         rdkit.Kekulize(rdkit_molecule)
         return cls.init_from_rdkit_mol(
             molecule=rdkit_molecule,
